.. _ilql:


Implicit Language Q-Learning (ILQL)
===================================

`ILQL <https://arxiv.org/pdf/2206.11871.pdf>`_ is an extension of Implicit Q-learning that can be used to finetune large language models (LLMs) with
reinforcement leaning from human feedback (RLHF).


Parameters
-----------

.. autoclass:: agilerl.algorithms.ilql.ILQL
  :members:
  :inherited-members:
